Pyrepo
======

.. image:: https://pypip.in/version/pyrepo/badge.png
    :target: https://pypi.python.org/pypi/pyrepo/
    :alt: Latest Version

.. image:: https://travis-ci.org/dghubble/pyrepo.png
    :target: https://travis-ci.org/dghubble/pyrepo
    :alt: Continuous Integration Testing

.. image:: https://pypip.in/download/pyrepo/badge.png
    :target: https://pypi.python.org/pypi/pyrepo/
    :alt: Downloads

.. image:: https://pypip.in/license/pyrepo/badge.png
    :target: https://pypi.python.org/pypi/pyrepo/
    :alt: License

Pyrepo is a repository abstraction package which provides a Python API for fetching and managing a variety of repositories.

